@@ -9,8 +9,6 @@ if(0 > ninsyou_check(3)){
    }
 
 
-
-
 echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
 echo "<HTML>";
 echo "<HEAD>";
@@ -51,7 +49,7 @@ if(0 == strlen($UNO)){
    exit;
    }
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -59,7 +57,7 @@ if(!$conn){
 
 
 if(0 < strlen($GEN)){
-   $result = pg_query($conn, "delete from monitor where uno=$UNO");
+   $result = db_query($conn, "delete from monitor where uno=$UNO");
 
    if(!$result){
       print("bud query set\n");
@@ -75,8 +73,8 @@ if(0 < strlen($GEN)){
 
 list_file_upload($CNAME, $GEN);
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 
 ?>
