@@ -187,6 +187,7 @@ if(0 == strcmp($MONITOR, "PORT")){
    echo "<option value=UDP>UDP";
    echo "<option value=TCP>TCP";
    echo "<option value=URL>URL";
+   echo "<option value=SSL>SSL";
    echo "<option value=SMTP>SMTP";
    echo "<option value=DHW>DHW";
    echo "<option value=SNTP>SNTP";
@@ -221,6 +222,36 @@ elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "DHW")){
    echo "<INPUT type='text' NAME=COM size='70' value='$COM'>";
    echo "</td></tr>";
    }
+
+elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "SSL")){
+   if(0 == strcmp($COM, "NOT")){
+      $COM = "14";
+      }
+
+   echo "<tr bgcolor='#D9DBED'><td>";
+   echo "CERTͭ0̵\n";
+   echo "</td><td>";
+   echo "<select size=1 NAME=COM>";
+   echo "<option value=$COM selected>$COM";
+   echo "<option value=0>̵";
+   echo "<option value=1>1";
+   echo "<option value=2>2";
+   echo "<option value=3>3";
+   echo "<option value=4>4";
+   echo "<option value=5>5";
+   echo "<option value=6>6";
+   echo "<option value=7>7";
+   echo "<option value=8>8";
+   echo "<option value=9>9";
+   echo "<option value=10>10";
+   echo "<option value=11>11";
+   echo "<option value=12>12";
+   echo "<option value=13>13";
+   echo "<option value=14>14";
+   echo "</select>";
+   echo "</td></tr>";
+   }
+
 elseif(0 == strcmp($MONITOR, "PORT") && 0 == strcmp($PROTO, "HOST")){
    echo "<tr bgcolor='#D9DBED'><td>";
    echo "̾IP\n";
