@@ -17,7 +17,7 @@ extern struct scan_buf sb;
 int path_check(char *chA)
 {
 int bu;
-char ch[24][BUF_COM];
+char ch[29][BUF_COM];
 int count = 0;
 char * non = "NOT";
 char * sock_ipaddr="SOCK_IPADDR";
@@ -42,6 +42,11 @@ char * thread_max="THREAD_MAX";
 char * tbuf_max="TBUF_MAX";
 char * life_onoff="LIFE_ONOFF";
 char * cron_onoff="CRON_ONOFF";
+char * midump_filename ="MIDUMP_FILE";
+char * midump_filename_2 ="MIDUMP_FILE_2";
+char * mid_max ="MID_MAX";
+char * thread_len="THREAD_LEN";
+char * mid_int="MID_INT";
 
 self_memcpy(ch[0], non, BUF_COM);
 self_memcpy(ch[1], sock_ipaddr, BUF_COM);
@@ -66,10 +71,15 @@ self_memcpy(ch[19], cron_path, BUF_COM);
 self_memcpy(ch[20], cron_file, BUF_COM);
 self_memcpy(ch[21], cron_list, BUF_COM);
 self_memcpy(ch[22], cron_onoff, BUF_COM);
+self_memcpy(ch[23], midump_filename, BUF_COM);
+self_memcpy(ch[24], mid_max, BUF_COM);
+self_memcpy(ch[25], thread_len, BUF_COM);
+self_memcpy(ch[26], mid_int, BUF_COM);
+self_memcpy(ch[27], midump_filename_2, BUF_COM);
 
 bu = 0;
 if(BUF_COM > strlen(chA)){
-   for(count=1; count < 23; count++){
+   for(count=1; count < 28; count++){
       if(0 == memcmp(chA, ch[count], (int)strlen(ch[count])+1)){
          bu=count;
          }
