@@ -23,7 +23,7 @@ printf("MALLOC: sacalloc():\n");
 #endif
 
 for(count_t = 0; count_t < gd.td.tbufmax; count_t ++){
-   if((sa.swap_data[count][count_t]=(char *)calloc(2, sizeof(char)))==NULL){exit(1);}
+   if((sa.swap_data[count][count_t]=(char *)calloc(BUF_LEN * 2, sizeof(char)))==NULL){exit(1);}
    #ifdef XMALLOC_BUG
    printf("MALLOC: sacalloc(): sa.swap_data[%d][%d]\n", count, count_t);
    #endif
@@ -52,5 +52,25 @@ return 0;
 
 
 
+int sanull(int count)
+{
+int count_t;
+
+#ifdef FREE_BUG
+printf("FREE: safree():\n");
+#endif
+
+for(count_t = 0; count_t < gd.td.tbufmax; count_t ++){
+   #ifdef XFREE_BUG
+   printf("FREE: sanull(): sa.swap_data[%d][%d] %s\n", count, count_t, sa.swap_data[count][count_t]);
+   #endif
+   sa.swap_data[count][count_t] = null_free(sa.swap_data[count][count_t]);
+   }
+return 0;
+}
+
+
+
+
 
 
