@@ -24,11 +24,14 @@ printf("MALLOC: satmpcalloc():\n");
 #endif
 
 for(count = 0; count < gd.td.tbufmax; count++){
-   if((sa.tmp_data[count]=(char *)calloc(2, sizeof(char)))==NULL){exit(1);}
+   if((sa.tmp_data[count]=(char *)calloc(BUF_LEN * 2, sizeof(char)))==NULL){exit(1);}
    }
 return 0;
 }
 
+
+
+
 int satmpfree(void)
 {
 int count;
@@ -46,3 +49,19 @@ return 0;
 
 
 
+int satmpnull(void)
+{
+int count;
+
+#ifdef FREE_BUG
+printf("FREE: satmpfree():\n");
+#endif
+
+for(count = 0; count < gd.td.tbufmax; count ++){
+   sa.tmp_data[count] = null_free(sa.tmp_data[count]);
+   }
+return 0;
+}
+
+
+
