@@ -164,7 +164,6 @@ for(co = 0; co < gd.td.tbufmax; co++){
                   #endif 
                   scan_comand(pd);
                   }
-               #ifdef NET_SNMP_IN
                else if(0 == self_memcmp(pd->sb.ch_tool, "SNMP")){
                   #ifdef MONITOR_BUG
                   printf("MONITOR: %s: %s: %s: %s:\n",
@@ -172,7 +171,6 @@ for(co = 0; co < gd.td.tbufmax; co++){
                   #endif 
                   scan_snmp(&pd->sb);
                   }
-               #endif
                else if(0 == self_memcmp(pd->sb.ch_tool, "SET")){
                   #ifdef MONITOR_BUG
                   printf("MONITOR: %s: %s: %s: %s:\n",
