@@ -178,7 +178,6 @@ if('#' != pd->sb.swap_2[0]){
                #endif 
                scan_comand(pd);
                }
-            #ifdef NET_SNMP_IN
             else if(0 == self_memcmp(pd->sb.ch_tool, "SNMP")){
                #ifdef MONITOR_BUG
                printf("MONITOR: %s: %s: %s: %s:\n",
@@ -186,7 +185,6 @@ if('#' != pd->sb.swap_2[0]){
                #endif 
                scan_snmp(&pd->sb);
                }
-            #endif
             else if(0 == self_memcmp(pd->sb.ch_tool, "SET")){
                #ifdef MONITOR_BUG
                printf("MONITOR: %s: %s: %s: %s:\n",
