@@ -112,9 +112,9 @@ else{
 printf("MYPEXEC: scan_comand(): コマンド出力 ---> %s -->カウント %d\n", pd->sb.ch_info, (int)strlen(pd->sb.ch_info));
 #endif
 
-swap_mem(pd->sb.ch_info, '\n', ' ', strlen(pd->sb.ch_info));
-swap_mem(pd->sb.ch_info, '\r', ' ', strlen(pd->sb.ch_info));
-swap_mem(pd->sb.ch_info, ',', ' ', strlen(pd->sb.ch_info));
+swap_mem(pd->sb.ch_info, '\n', ' ');
+swap_mem(pd->sb.ch_info, '\r', ' ');
+swap_mem(pd->sb.ch_info, ',', ' ');
 
 if(1 > (int)strlen(pd->sb.ch_info)){
    pd->sb.check_stat = 0;
