@@ -93,6 +93,8 @@ char * ip_addr = ipx;
 char pas[BUF_URL];
 char * url_pass = pas;
 char * ip_addr2 = ipa2;
+char ntopbuff[256];
+
 struct sockaddr_in send_addr;
 struct timeval tv;
 struct ip *ip;
@@ -131,7 +133,8 @@ if(0 == (int)send_addr.sin_addr.s_addr || resoip == (int)NULL){
    return backdata;
    }
 
-ip_addr2 = inet_ntoa(send_addr.sin_addr);
+// ip_addr2 = inet_ntoa(send_addr.sin_addr);
+ip_addr2 = inet_ntop(AF_INET, &send_addr.sin_addr, ntopbuff, sizeof(ntopbuff));
 
 #ifdef ICMP_BUG
 printf("ICMP: scan_icmp(1): ICMP host<%s> ip<%s>\n", ip_addr, ip_addr2);
@@ -202,7 +205,9 @@ while(1){
 
          if(rtt > (timeout * coe)){
             backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms TIMEOUT=%dms %s",
-            inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)), rtt, (timeout * coe), ICMP_5);
+//          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
+            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
+            rtt, (timeout * coe), ICMP_5);
             #ifdef ICMP_BUG
             printf("ICMP: scan_icmp(5): RECV RAW DATA NG! %s\n",  backdata);
             #endif
@@ -213,7 +218,9 @@ while(1){
 
          else if(rtt <= (timeout * coe)){
             backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms TIMEOUT=%dms %s",
-            inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)), rtt, (timeout * coe), ICMP_6);
+//          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr))
+            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
+            rtt, (timeout * coe), ICMP_6);
             #ifdef ICMP_BUG
             printf("ICMP: scan_icmp(6): RECV RAW DATA OK! %s\n", backdata);
             #endif
@@ -223,7 +230,9 @@ while(1){
             }
          else{
             backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms TIMEOUT=%dms %s",
-            inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)), rtt, (timeout * coe), ICMP_5);
+//          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
+            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
+            rtt, (timeout * coe), ICMP_5);
             #ifdef ICMP_BUG
             printf("ICMP: scan_icmp(5): RTT err! %s\n",  backdata);
             #endif
@@ -245,7 +254,8 @@ while(1){
       // 到達出来ないと帰った場合
       else if(icmp->icmp_type == ICMP_UNREACH){
          backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
-            inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
+//          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
+            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
             tv.tv_sec*1000.0 + tv.tv_usec/1000.0, ICMP_7);
          #ifdef ICMP_BUG
          printf("ICMP: scan_icmp(8): RECV RAW %s type<%d>\n", backdata, icmp->icmp_type);
@@ -256,7 +266,8 @@ while(1){
          }
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
-            inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
+//          inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
+            inet_ntop(AF_INET, (struct in_addr *)(long int)&(ip->ip_src.s_addr), ntopbuff, sizeof(ntopbuff)),
             tv.tv_sec*1000.0 + tv.tv_usec/1000.0, ICMP_4);
          #ifdef ICMP_BUG
          printf("ICMP: scan_icmp(10): RECV RAW %s type<%d>\n", backdata, icmp->icmp_type);
