@@ -82,6 +82,7 @@ char recvd[BUF_LEN];
 char sendd[BUF_LEN];
 char * recvdata = recvd;
 char * senddata = sendd;
+char buff[256];
 
 memset(recvdata, 0x00, BUF_LEN);
 memset(senddata, 0x00, BUF_LEN);
@@ -117,7 +118,8 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
    return backdata;
    }
 
-ip_addr = inet_ntoa(my_addr.sin_addr);
+// ip_addr = inet_ntoa(my_addr.sin_addr);
+ip_addr = inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff));
 
 #ifdef SMTP_BUG
 printf("SMTP: scan_smtp_connect(0): %s %s %d\n", url_dom, ip_addr, port);
