@@ -31,6 +31,8 @@ char ip[BUF_URL];
 char * ip_addr = ip;
 char pas[BUF_URL];
 char * url_pass = pas;
+char buff[256];
+
 int sk, re, retval, arglen, port2;
 unsigned long resoip;
 struct sockaddr_in my_addr;
@@ -79,7 +81,8 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
    return backdata;
    }
 
-ip_addr2 = inet_ntoa(my_addr.sin_addr);
+// ip_addr2 = inet_ntoa(my_addr.sin_addr);
+ip_addr2 = inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff));
 
 #ifdef TCP_BUG
 printf("TCP: scan_tcp_connetc(3): start TCPCHECK host<%s> ip<%s>\n", ip_addr2, ip_addr);
