@@ -28,6 +28,7 @@ char * scan_udp_connect(int port, char * url_data, char * backdata, int timeout,
 char ipa2[IP_LEN];
 char * ip_addr2 = ipa2;
 char buff[1024];
+char ntopbuff[256];
 
 char ip[BUF_URL];
 char * ip_addr = ip;
@@ -68,7 +69,8 @@ if(0 == (int)send_addr.sin_addr.s_addr || resoip == (int)NULL){
    return backdata;
    }
 
-ip_addr2 = inet_ntoa(send_addr.sin_addr);
+// ip_addr2 = inet_ntoa(send_addr.sin_addr);
+ip_addr2 = inet_ntop(AF_INET, &send_addr.sin_addr, ntopbuff, sizeof(ntopbuff));
 
 #ifdef UDP_BUG
 printf("UDP: scan_udp_connect(2): UDP host<%s> ip<%s>\n",ip_addr2, ip_addr);
