@@ -40,7 +40,7 @@ char * url_dom = dom;
 char * url_pass = pass;
 char * recvdata = recvd;
 char * senddata = sendd;
-
+char buff[256];
 
 dcount = 0;
 arglen = sizeof(int);
@@ -94,7 +94,8 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
    return backdata;
    }
 
-ip_addr = inet_ntoa(my_addr.sin_addr);
+// ip_addr = inet_ntoa(my_addr.sin_addr);
+ip_addr = inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff));
 
 #ifdef URL_BUG
 printf("URL_BUG: scan_url_connect(3): %s\n", ip_addr);
