@@ -22,14 +22,16 @@
 
 #include"sitar_scan.h"
 #include"sitar_com.h"
+#include"sitar_ssl.h"
 #include <almemsys/almemsys.h>
 #include"jpreturn.h"
 #include "version.h"
 
+
 // 259200 = 3day 証明書の期限が切れる3日前の時間
 #define AF_TIME 259200 
 
-char *  verify_ssl(char * data, SSL *ssl, int * err);
+// char *  verify_ssl(char * data, SSL *ssl, int * err);
 
 // #define SSL_BUG
 
@@ -55,6 +57,7 @@ char * ssl_senddata;
 char * backdata;
 char * swapdata = swa;
 char * recvdata = rec;
+char buff[256];
 
 extern char *optarg;
 
@@ -169,7 +172,8 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
    exit(1);
    }
 
-ip_addr = inet_ntoa(my_addr.sin_addr);
+// ip_addr = inet_ntoa(my_addr.sin_addr);
+ip_addr = inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff));
 
 #ifdef SSL_BUG
 printf("SSL_BUG: scan_ssl_connect(3): %s\n", ip_addr);
