@@ -62,7 +62,7 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
                   (pd->life.life_int + pd->life.life_los + INT_PLUS),
                   (char)0x05);
      }
-  else if(0 == (self_memcmp("CRONFILE", pd->rec.data))){
+  else if(0 == (self_memcmp("CRONFILE", pd->rec.data)) && gd.cron_onoff == 1){
      swap = file_send2(gd.ms.sk[pd->rec.fdno],
                   pd->file.cronfile_filename,
                   swap,
@@ -70,7 +70,7 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
                   (pd->life.life_int + pd->life.life_los + INT_PLUS),
                   (char)0x05);
      }
-  else if(0 == (self_memcmp("CRONLIST", pd->rec.data))){
+  else if(0 == (self_memcmp("CRONLIST", pd->rec.data)) && gd.cron_onoff == 1){
      swap = file_send2(gd.ms.sk[pd->rec.fdno],
                   pd->file.cronlist_filename,
                   swap,
