@@ -26,8 +26,8 @@ char * time_data = (char *)calloc(BUF_DEFLEN, sizeof(char));
 
 ret = 0;
 
-swap_mem(data1, '\n', ' ', (int)strlen(data1));
-swap_mem(data2, '\n', ' ', (int)strlen(data2));
+swap_mem(data1, '\n', ' ');
+swap_mem(data2, '\n', ' ');
 
 time_data = time_getr(time_data);
 
