@@ -6,6 +6,7 @@
 #include<sys/socket.h>
 #include<netinet/in.h>
 #include<arpa/inet.h>
+#include<errno.h>
 #include<pthread.h>
 
 #include"zither.h"
@@ -33,6 +34,10 @@ int mail_grsend( char * iserver,
                  )
 {
 pthread_t pt_t;
+int tret;
+
+errno = 0;
+tret = 0;
 
 mail_data_t * mdd;
 if((mdd = (mail_data_t *)malloc(sizeof(mail_data_t)))==NULL){exit(1);}
@@ -52,7 +57,9 @@ mdd->isubject = safe_sprintf(mdd->isubject, BUF_MAX, "Subject: %s", isubject);
 mdd->idata = safe_ujtoj(mdd->idata);
 
 // thread 分岐　分岐先でデタッチ
-pthread_create( &pt_t, NULL, (void *)mail_grsend_t, mdd);
+if((tret = pthread_create( &pt_t, NULL, (void *)mail_grsend_t, mdd)) != 0){
+   fprintf(stderr,"life_logi.c life_logi(): pthread_create %d\n", tret);
+   }
 
 // ここには戻らない。
 return 0;
