@@ -42,6 +42,8 @@ int print_conf(void)
    fprintf(stdout,"-- MYSQL_PASSWORD (mysql user password)        = %s\n",gd.mysql.mysql_password);
    fprintf(stdout,"-- MYSQL_DB       (mysql database name)        = %s\n",gd.mysql.mysql_db);
    fprintf(stdout,"-- DB_SELECT      (select db 'PGSQL'or'MYSQL') = %s\n",gd.db_select);
+   fprintf(stdout,"-- ON_BCC         (select bcc address)         = %s\n",gd.on_bcc);
+   fprintf(stdout,"-- CRON_ONOFF     (enable cron mode 1)         = %d\n",gd.cron_onoff);
 
    fprintf(stdout,"Version %s\n", CL_VAR);
 
