@@ -171,7 +171,9 @@ if((sk = socket(AF_INET, SOCK_STREAM, 0))==-1){
 
 my_addr.sin_family = AF_INET;
 my_addr.sin_port = htons(port);
-my_addr.sin_addr.s_addr = inet_addr(ip_addr);
+// my_addr.sin_addr.s_addr = inet_addr(ip_addr);  20081212 修正
+swap_mem(ip_addr, '\n', 0x00);
+inet_pton(AF_INET, ip_addr, &my_addr.sin_addr.s_addr);
 
 if(connect(sk, (struct sockaddr *)(long int)&my_addr, sizeof(my_addr)) == -1){
    fprintf(stderr,"Not connection line=%d file=%s err=%s\n", __LINE__, __FILE__, strerror(errno));
